pub struct UpdateNodeOptions {
pub location_uuid: Option<Uuid>,
pub backup_configuration_uuid: Option<Option<Uuid>>,
pub name: Option<CompactString>,
pub description: Option<Option<CompactString>>,
pub deployment_enabled: Option<bool>,
pub maintenance_enabled: Option<bool>,
pub public_url: Option<Option<CompactString>>,
pub url: Option<CompactString>,
pub sftp_host: Option<Option<CompactString>>,
pub sftp_port: Option<u16>,
pub memory: Option<i64>,
pub disk: Option<i64>,
}Fields
location_uuid: Option<Uuid>backup_configuration_uuid: Option<Option<Uuid>>name: Option<CompactString>description: Option<Option<CompactString>>deployment_enabled: Option<bool>maintenance_enabled: Option<bool>public_url: Option<Option<CompactString>>url: Option<CompactString>sftp_host: Option<Option<CompactString>>sftp_port: Option<u16>memory: Option<i64>disk: Option<i64>Trait Implementations
Sourceimpl Clone for UpdateNodeOptions
impl Clone for UpdateNodeOptions
Sourcefn clone(&self) -> UpdateNodeOptions
fn clone(&self) -> UpdateNodeOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UpdateNodeOptions
impl ComposeSchema for UpdateNodeOptions
Sourceimpl Default for UpdateNodeOptions
impl Default for UpdateNodeOptions
Sourcefn default() -> UpdateNodeOptions
fn default() -> UpdateNodeOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateNodeOptions
impl<'de> Deserialize<'de> for UpdateNodeOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for UpdateNodeOptions
impl Serialize for UpdateNodeOptions
Sourceimpl ToSchema for UpdateNodeOptions
impl ToSchema for UpdateNodeOptions
Sourceimpl Validate for UpdateNodeOptions
impl Validate for UpdateNodeOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for UpdateNodeOptions
impl RefUnwindSafe for UpdateNodeOptions
impl Send for UpdateNodeOptions
impl Sync for UpdateNodeOptions
impl Unpin for UpdateNodeOptions
impl UnwindSafe for UpdateNodeOptions